@@ -1981,7 +1981,10 @@ typedef struct private_area
 	unsigned char label[WAN_IF_LABEL_SZ+1];
 
 	unsigned char tdm_span_voice_api;
-
+	uint32_t	rx_error_cnt;
+	wan_ticks_t rx_error_timeout;
+	wan_ticks_t	rx_error_threshold_down_timeout;
+	
 }private_area_t;
 
 
